@@ -1,6 +1,6 @@
 #include <stack>
 #include <RcppArmadillo.h>
-#include <omp.h>
+#include "myomp.h"
 
 #define ALL 0
 #define LAST 1
